;	A simple textured house macro
;	This is an example how to use bitmaps and the TexPoly() instruction.
;
;	Macro( house01.scm  NN  EE  rot  color1 color2  bitmap )
;	                    1   2    3     4      5        6
;
;	parameters:
;	1. NN		Latitude
;	2. EE		Longitude
;	3. rot		rotation angle to rotate the house
;	4. color1	wall color, used if textured building option is off
;	5. color2	roof color, used if textured building option is off
;	6. bitmap	the name of the bitmap file, copy this file into
;			the ..\texture directory
;
;
Area( 5  %1  %2  12 )
    PerspectiveCall( :house1 )
    ShadowCall( :house2 )
    Jump( : )

:house1
    Perspective
:house2
    RefPoint( 7 :house_end 0.5 %1  %2 )
    RotatedCall( :house3 0 0 %3 )
:house_end
    Return

:house3
    Points( 0
	-32 0  16	; 0, North West corner, bottom
	 32 0  16	; 1, NE corner, bottom
	 32 0 -16	; 2, SE corner, bottom
	-32 0 -16	; 3, SW corner, bottom
	-32 8  16	; 4, NW corner
	 32 8  16	; 5, NE corner
	 32 32 0	; 6, East roof top
	 32 8 -16	; 7, SE corner
	-32 8 -16	; 8, SW corner
	-32 32 0	; 9, West roof top
    )

    ; crash detection
    IfVarRange( :nocrash 37E -32  32 )	; test delta x distance
    IfVarRange( :nocrash 386 -16  16 )	; test delta y distance
    IfVarRange( :nocrash 382   0  32 )	; test the altitude
    SetVar( 284 14 )			; set the crash flag with building
					; crash code
:nocrash
    IfVarAnd( :notexture 342 FFFF )	; check the textured_building flag
    ;
    ; This is the textured version of the house. It is drawn if the textured
    ; building option in the preferences menu is enabled.
    ;
    SurfaceColor( %4 F0 )
    Bitmap( %6 0 0 0 0 )
    Inst_7D				; reduce bitmap distortion
    TexPoly( a
	0  0   255
	1  255 255
	5  255 223
	4  0   223
    )
    Inst_7D
    TexPoly( a
	1  127 127
	5  127  95
	6   63   0
	7    0  95
	2    0 127
    )
    Inst_7D
    TexPoly( a
	2  0   255
	3  255 255
	8  255 223
	7  0   223
    )
    Inst_7D
    TexPoly( a
	3  255 127
	8  255  95
	9  191   0
	4  128  95
	0  128 127
    )
    SurfaceColor( %5 F0 )
    Inst_7D
    TexPoly( a
	7  255 222
	6  255 128
	9  0   128
	8  0   222
    )
    Inst_7D
    TexPoly( a
	4  255 222
	9  255 128
	6  0   128
	5  0   222
    )
    Return

:notexture
    ; this is the non textured house. It is drawn if the textured building
    ; option in the preferences menu is switched off.
    ;
    SurfaceColor( %4 F0 )
    Poly( a 0 1 5 4 )
    Poly( a 1 5 6 7 2 )
    Poly( a 2 3 8 7 )
    Poly( a 3 8 9 4 0 )

    SurfaceColor( %5 F0 )
    Poly( a 7 6 9 8 )
    Poly( a 4 9 6 5 )
    return

EndA
